@@ -25,8 +25,8 @@ SOX_FORMAT_HANDLER(ima)
   static unsigned const write_encodings[] = {SOX_ENCODING_IMA_ADPCM, 4, 0, 0};
   static sox_format_handler_t handler = {SOX_LIB_VERSION_CODE,
     "Raw IMA ADPCM", names, SOX_FILE_MONO,
-    sox_ima_start, sox_vox_read, sox_vox_stopread,
-    sox_ima_start, sox_vox_write, sox_vox_stopwrite,
+    lsx_ima_start, lsx_vox_read, lsx_vox_stopread,
+    lsx_ima_start, lsx_vox_write, lsx_vox_stopwrite,
     lsx_rawseek, write_encodings, NULL, sizeof(adpcm_io_t)
   };
   return &handler;
