@@ -24,6 +24,7 @@
 
 #include "sox_i.h"
 #include "fft4g.h"
+#include "getopt.h"
 #define  FIFO_SIZE_T int
 #include "fifo.h"
 #include <assert.h>
@@ -48,7 +49,7 @@ static sample_t * prepare_coefs(raw_coef_t const * coefs, int num_coefs,
     for (j = num_phases - 1; j >= 0; --j) {
       double f0 = fm1, b = 0, c = 0, d = 0; /* = 0 to kill compiler warning */
       int pos = i * num_phases + j - 1;
-      fm1 = (pos ? coefs[pos - 1] : 0) * multiplier;
+      fm1 = (pos > 0 ? coefs[pos - 1] : 0) * multiplier;
       switch (interp_order) {
         case 1: b = f1 - f0; break;
         case 2: b = f1 - (.5 * (f2+f0) - f1) - f0; c = .5 * (f2+f0) - f1; break;
@@ -68,15 +69,13 @@ static sample_t * prepare_coefs(raw_coef_t const * coefs, int num_coefs,
 }
 
 typedef struct {
-  int        dft_length, num_taps;
+  int        dft_length, num_taps, post_peak;
   sample_t   * coefs;
 } half_band_t;      /* Note: not half-band as in symmetric about Fn/2 (Fs/4) */
 
 typedef struct {    /* Data that are shared between channels and filters */
   sample_t   * poly_fir_coefs;
   half_band_t half_band[2];    /* [0]: halve; [1]: down/up: halve/double */
-  sample_t   * sin_cos_table;  /* For Ooura fft */
-  int        * bit_rev_table;  /* ditto */
 } rate_shared_t;
 
 struct stage;
@@ -142,7 +141,7 @@ static void half_sample(stage_t * p, fifo_t * output_fifo)
     fifo_trim_by(output_fifo, (f->dft_length + overlap) >> 1);
     memcpy(output, input, f->dft_length * sizeof(*output));
 
-    rdft(f->dft_length, 1, output, s->bit_rev_table, s->sin_cos_table);
+    lsx_rdft(f->dft_length, 1, output, lsx_fft_br, lsx_fft_sc);
     output[0] *= f->coefs[0];
     output[1] *= f->coefs[1];
     for (i = 2; i < f->dft_length; i += 2) {
@@ -150,7 +149,7 @@ static void half_sample(stage_t * p, fifo_t * output_fifo)
       output[i  ] = f->coefs[i  ] * tmp - f->coefs[i+1] * output[i+1];
       output[i+1] = f->coefs[i+1] * tmp + f->coefs[i  ] * output[i+1];
     }
-    rdft(f->dft_length, -1, output, s->bit_rev_table, s->sin_cos_table);
+    lsx_rdft(f->dft_length, -1, output, lsx_fft_br, lsx_fft_sc);
 
     for (j = 1, i = 2; i < f->dft_length - overlap; ++j, i += 2)
       output[j] = output[i];
@@ -175,7 +174,7 @@ static void double_sample(stage_t * p, fifo_t * output_fifo)
     for (j = i = 0; i < f->dft_length; ++j, i += 2)
       output[i] = input[j], output[i+1] = 0;
 
-    rdft(f->dft_length, 1, output, s->bit_rev_table, s->sin_cos_table);
+    lsx_rdft(f->dft_length, 1, output, lsx_fft_br, lsx_fft_sc);
     output[0] *= f->coefs[0];
     output[1] *= f->coefs[1];
     for (i = 2; i < f->dft_length; i += 2) {
@@ -183,7 +182,7 @@ static void double_sample(stage_t * p, fifo_t * output_fifo)
       output[i  ] = f->coefs[i  ] * tmp - f->coefs[i+1] * output[i+1];
       output[i+1] = f->coefs[i+1] * tmp + f->coefs[i  ] * output[i+1];
     }
-    rdft(f->dft_length, -1, output, s->bit_rev_table, s->sin_cos_table);
+    lsx_rdft(f->dft_length, -1, output, lsx_fft_br, lsx_fft_sc);
   }
 }
 
@@ -195,7 +194,7 @@ static double * make_lpf(int num_taps, double Fc, double beta, double scale)
   for (i = 0; i <= m / 2; ++i) {
     double x = M_PI * (i - .5 * m), y = 2. * i / m - 1;
     h[i] = x? sin(Fc * x) / x : Fc;
-    sum += h[i] *= bessel_I_0(beta * sqrt(1 - y * y));
+    sum += h[i] *= lsx_bessel_I_0(beta * sqrt(1 - y * y));
     if (m - i != i)
       sum += h[m - i] = h[i];
   }
@@ -203,18 +202,28 @@ static double * make_lpf(int num_taps, double Fc, double beta, double scale)
   return h;
 }
 
+#define TO_6dB .5869
+#define TO_3dB ((2/3.) * (.5 + TO_6dB))
+#define MAX_TBW0 36.
+#define MAX_TBW0A (MAX_TBW0 / (1 + TO_3dB))
+#define MAX_TBW3 floor(MAX_TBW0 * TO_3dB)
+#define MAX_TBW3A floor(MAX_TBW0A * TO_3dB)
+
 static double * design_lpf(
     double Fp,      /* End of pass-band; ~= 0.01dB point */
     double Fc,      /* Start of stop-band */
     double Fn,      /* Nyquist freq; e.g. 0.5, 1, PI */
+    sox_bool allow_aliasing,
     double att,     /* Stop-band attenuation in dB */
     int * num_taps, /* (Single phase.)  0: value will be estimated */
     int k)          /* Number of phases; 0 for single-phase */
 {
   double tr_bw, beta;
 
+  if (allow_aliasing)
+    Fc += (Fc - Fp) * TO_3dB;
   Fp /= Fn, Fc /= Fn;        /* Normalise to Fn = 1 */
-  tr_bw = .5869 * (Fc - Fp); /* Transition band-width: 6dB to stop points */
+  tr_bw = TO_6dB * (Fc - Fp); /* Transition band-width: 6dB to stop points */
 
   if (*num_taps == 0) {        /* TODO this could be cleaner, esp. for k != 0 */
     double n160 = (.0425* att - 1.4) /  tr_bw;    /* Half order for att = 160 */
@@ -229,17 +238,74 @@ static double * design_lpf(
   return make_lpf(*num_taps, (Fc - tr_bw) / k, beta, (double)k);
 }
 
-static int set_dft_length(int num_taps) /* Set to 4 x nearest power of 2 */
+static void fir_to_phase(double * * h, int * len,
+    int * post_len, double phase0)
 {
-  int result, n = num_taps;
-  for (result = 8; n > 2; result <<= 1, n >>= 1);
-  result = range_limit(result, 4096, 131072);
-  assert(num_taps * 2 < result);
-  return result;
+  double * work, phase = (phase0 > 50 ? 100 - phase0 : phase0) / 50;
+  int work_len, begin, end, peak = 0, i = *len;
+
+  for (work_len = 32; i > 1; work_len <<= 1, i >>= 1);
+  work = calloc(work_len, sizeof(*work));
+  for (i = 0; i < *len; ++i) work[i] = (*h)[i];
+
+  lsx_safe_rdft(work_len, 1, work); /* Cepstral: */
+  work[0] = log(fabs(work[0])), work[1] = log(fabs(work[1]));
+  for (i = 2; i < work_len; i += 2) {
+    work[i] = log(sqrt(sqr(work[i]) + sqr(work[i + 1])));
+    work[i + 1] = 0;
+  }
+  lsx_safe_rdft(work_len, -1, work);
+  for (i = 0; i < work_len; ++i) work[i] *= 2. / work_len;
+  for (i = 1; i < work_len / 2; ++i) { /* Window to reject acausal components */
+    work[i] *= 2;
+    work[i + work_len / 2] = 0;
+  }
+  lsx_safe_rdft(work_len, 1, work);
+
+  /* Some filters require phase unwrapping at this point.  Ours give dis-
+   * continuities only in the stop band, so no need to unwrap in this case. */
+
+  for (i = 2; i < work_len; i += 2) /* Interpolate between linear & min phase */
+    work[i + 1] = phase * M_PI * .5 * i + (1 - phase) * work[i + 1];
+
+  work[0] = exp(work[0]), work[1] = exp(work[1]);
+  for (i = 2; i < work_len; i += 2) {
+    double x = exp(work[i]);
+    work[i    ] = x * cos(work[i + 1]);
+    work[i + 1] = x * sin(work[i + 1]);
+  }
+  lsx_safe_rdft(work_len, -1, work);
+  for (i = 0; i < work_len; ++i) work[i] *= 2. / work_len;
+
+  for (i = 1; i < work_len; ++i) if (work[i] > work[peak])  /* Find peak pos. */
+    peak = i;                                           /* N.B. peak val. > 0 */
+
+  if (phase == 0)
+    begin = 0;
+  else if (phase == 1)
+    begin = 1 + (work_len - *len) / 2;
+  else {
+    if (peak < work_len / 4) { /* Low phases can wrap impulse, so unwrap: */
+      memmove(work + work_len / 4, work, work_len / 2 * sizeof(*work));
+      memmove(work, work + work_len * 3 / 4, work_len / 4 * sizeof(*work));
+      peak += work_len / 4;
+    }
+    begin = (.997 - (2 - phase) * .22) * *len + .5;
+    end   = (.997 + (0 - phase) * .22) * *len + .5;
+    begin = peak - begin - (begin & 1);
+    end   = peak + 1 + end + (end & 1);
+    *len = end - begin;
+    *h = realloc(*h, *len * sizeof(**h));
+  }
+  for (i = 0; i < *len; ++i)
+    (*h)[i] = work[begin + (phase0 > 50 ? *len - 1 - i : i)];
+  *post_len = phase0 > 50 ? peak - begin : begin + *len - (peak + 1);
+  free(work);
 }
 
 static void half_band_filter_init(rate_shared_t * p, unsigned which,
-    int num_taps, sample_t const h[], double Fp, double atten, int multiplier)
+    int num_taps, sample_t const h[], double Fp, double atten, int multiplier,
+    double phase, sox_bool allow_aliasing)
 {
   half_band_t * f = &p->half_band[which];
   int dft_length, i;
@@ -247,15 +313,23 @@ static void half_band_filter_init(rate_shared_t * p, unsigned which,
   if (f->num_taps)
     return;
   if (h) {
-    dft_length = set_dft_length(num_taps);
+    dft_length = lsx_set_dft_length(num_taps);
     f->coefs = calloc(dft_length, sizeof(*f->coefs));
     for (i = 0; i < num_taps; ++i)
       f->coefs[(i + dft_length - num_taps + 1) & (dft_length - 1)]
           = h[abs(num_taps / 2 - i)] / dft_length * 2 * multiplier;
+    f->post_peak = num_taps / 2;
   }
   else {
-    double * h = design_lpf(Fp, 1., 2., atten, &num_taps, 0);
-    dft_length = set_dft_length(num_taps);
+    /* Adjustment to negate att degradation with intermediate phase */
+    double att = phase && phase != 50 && phase != 100? atten * (34./33) : atten;
+    double * h = design_lpf(Fp, 1., 2., allow_aliasing, att, &num_taps, 0);
+
+    if (phase != 50)
+      fir_to_phase(&h, &num_taps, &f->post_peak, phase);
+    else f->post_peak = num_taps / 2;
+
+    dft_length = lsx_set_dft_length(num_taps);
     f->coefs = calloc(dft_length, sizeof(*f->coefs));
     for (i = 0; i < num_taps; ++i)
       f->coefs[(i + dft_length - num_taps + 1) & (dft_length - 1)]
@@ -265,13 +339,9 @@ static void half_band_filter_init(rate_shared_t * p, unsigned which,
   assert(num_taps & 1);
   f->num_taps = num_taps;
   f->dft_length = dft_length;
-  sox_debug("fir_len=%i dft_length=%i Fp=%g atten=%g mult=%i",
+  lsx_debug("fir_len=%i dft_length=%i Fp=%g atten=%g mult=%i",
       num_taps, dft_length, Fp, atten, multiplier);
-  if (!p->bit_rev_table) {
-    p->bit_rev_table = calloc(dft_br_len(dft_length),sizeof(*p->bit_rev_table));
-    p->sin_cos_table = calloc(dft_sc_len(dft_length),sizeof(*p->sin_cos_table));
-  }
-  rdft(dft_length, 1, f->coefs, p->bit_rev_table, p->sin_cos_table);
+  lsx_safe_rdft(dft_length, 1, f->coefs);
 }
 
 #include "rate_filters.h"
@@ -288,15 +358,17 @@ typedef struct {
 #define last_stage p->stages[p->level]
 #define post_stage p->stages[p->level + 1]
 
-typedef enum {Default = -1, Quick, Low, Medium, High, Very, Ultra} quality_t;
+typedef enum {Default = -1, Quick, Low, Medium, High, Very} quality_t;
 
-static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality_t quality, int interp_order)
+static void rate_init(rate_t * p, rate_shared_t * shared, double factor,
+    quality_t quality, int interp_order, double phase, double bandwidth,
+    sox_bool allow_aliasing)
 {
   int i, mult, divisor = 1;
 
   assert(factor > 0);
   p->factor = factor;
-  if (quality < Quick || quality > Ultra)
+  if (quality < Quick || quality > Very)
     quality = High;
   if (quality != Quick) {
     const int max_divisor = 2048;      /* Keep coef table size ~< 500kb */
@@ -323,7 +395,7 @@ static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality
     assert(!last_stage.step.parts.fraction);
   else if (quality != Quick)
     assert(!last_stage.step.parts.integer);
-  sox_debug("i/o=%g; %.9g:%i @ level %i", p->factor, factor, divisor, p->level);
+  lsx_debug("i/o=%g; %.9g:%i @ level %i", p->factor, factor, divisor, p->level);
 
   mult = 1 + p->upsample; /* Compensate for zero-stuffing in double_sample */
   p->input_stage_num = -p->upsample;
@@ -350,13 +422,13 @@ static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality
     if (!last_stage.shared->poly_fir_coefs) {
       int num_taps = 0, phases = divisor == 1? (1 << f1->phase_bits) : divisor;
       raw_coef_t * coefs =
-          design_lpf(f->pass, f->stop, 1., f->att, &num_taps, phases);
+          design_lpf(f->pass, f->stop, 1., sox_false, f->att, &num_taps, phases);
       assert(num_taps == f->num_coefs * phases - 1);
       last_stage.shared->poly_fir_coefs =
           prepare_coefs(coefs, f->num_coefs, phases, interp_order, mult);
-      sox_debug("fir_len=%i phases=%i coef_interp=%i mult=%i size=%s",
+      lsx_debug("fir_len=%i phases=%i coef_interp=%i mult=%i size=%s",
           f->num_coefs, phases, interp_order, mult,
-          sigfigs3((num_taps + 1) * (interp_order + 1) * sizeof(sample_t)));
+          lsx_sigfigs3((num_taps + 1) * (interp_order + 1) * sizeof(sample_t)));
       free(coefs);
     }
     last_stage.fn = f1->fn;
@@ -369,27 +441,28 @@ static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality
     typedef struct {int len; sample_t const * h; double bw, a;} filter_t;
     static filter_t const filters[] = {
       {2 * array_length(half_fir_coefs_low) - 1, half_fir_coefs_low, 0,0},
-      {0, NULL, .986, 110}, {0, NULL, .986, 125},
-      {0, NULL, .986, 165}, {0, NULL, .996, 165},
-    };
+      {0, NULL, .931, 110}, {0, NULL, .931, 125}, {0, NULL, .931, 170}};
     filter_t const * f = &filters[quality - Low];
+    double att = allow_aliasing? (34./33)* f->a : f->a; /* negate att degrade */
+    double bw = bandwidth? 1 - (1 - bandwidth / 100) / TO_3dB : f->bw;
+    double min = 1 - (allow_aliasing? MAX_TBW0A : MAX_TBW0) / 100;
     assert((size_t)(quality - Low) < array_length(filters));
-    half_band_filter_init(shared, p->upsample, f->len, f->h, f->bw, f->a, mult);
+    half_band_filter_init(shared, p->upsample, f->len, f->h, bw, att, mult, phase, allow_aliasing);
     if (p->upsample) {
       pre_stage.fn = double_sample; /* Finish off setting up pre-stage */
-      pre_stage .preload = shared->half_band[1].num_taps >> 2;
+      pre_stage.preload = shared->half_band[1].post_peak >> 1;
        /* Start setting up post-stage; TODO don't use dft for short filters */
-      if ((1 - p->factor) / (1 - f->bw) > 2)
-        half_band_filter_init(shared, 0, 0, NULL, max(p->factor, .64), f->a, 1);
+      if ((1 - p->factor) / (1 - bw) > 2)
+        half_band_filter_init(shared, 0, 0, NULL, max(p->factor, min), att, 1, phase, allow_aliasing);
       else shared->half_band[0] = shared->half_band[1];
     }
     else if (p->level > 0 && p->output_stage_num > p->level) {
-      double pass = f->bw * divisor / factor / 2;
-      if ((1 - pass) / (1 - f->bw) > 2)
-        half_band_filter_init(shared, 1, 0, NULL, max(pass, .64), f->a, 1);
+      double pass = bw * divisor / factor / 2;
+      if ((1 - pass) / (1 - bw) > 2)
+        half_band_filter_init(shared, 1, 0, NULL, max(pass, min), att, 1, phase, allow_aliasing);
     }
     post_stage.fn = half_sample;
-    post_stage.preload = shared->half_band[0].num_taps >> 1;
+    post_stage.preload = shared->half_band[0].post_peak;
   }
   else if (quality == Low && !p->upsample) {    /* dft is slower here, so */
     post_stage.fn = half_sample_low;            /* use normal convolution */
@@ -400,7 +473,7 @@ static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality
     stage_t * s = & p->stages[p->level - 1];
     if (shared->half_band[1].num_taps) {
       s->fn = half_sample;
-      s->preload = shared->half_band[1].num_taps >> 1;
+      s->preload = shared->half_band[1].post_peak;
       s->which = 1;
     }
     else *s = post_stage;
@@ -412,10 +485,10 @@ static void rate_init(rate_t * p, rate_shared_t * shared, double factor, quality
       s->pre_post = 2 * (array_length(half_fir_coefs_25) - 1);
       s->preload = s->pre = s->pre_post >> 1;
     }
-    fifo_create(&s->fifo, sizeof(sample_t));
+    fifo_create(&s->fifo, (int)sizeof(sample_t));
     memset(fifo_reserve(&s->fifo, s->preload), 0, sizeof(sample_t)*s->preload);
     if (i < p->output_stage_num)
-      sox_debug("stage=%-3ipre_post=%-3ipre=%-3ipreload=%i",
+      lsx_debug("stage=%-3ipre_post=%-3ipre=%-3ipreload=%i",
           i, s->pre_post, s->pre, s->preload);
   }
 }
@@ -451,7 +524,7 @@ static void rate_flush(rate_t * p)
 
   if ((int)remaining > 0) {
     while ((size_t)fifo_occupancy(fifo) < remaining) {
-      rate_input(p, buff, 1024);
+      rate_input(p, buff, (size_t) 1024);
       rate_process(p);
     }
     fifo_trim_to(fifo, (int)remaining);
@@ -467,8 +540,6 @@ static void rate_close(rate_t * p)
 
   for (i = p->input_stage_num; i <= p->output_stage_num; ++i)
     fifo_delete(&p->stages[i].fifo);
-  free(shared->bit_rev_table);
-  free(shared->sin_cos_table);
   free(shared->half_band[0].coefs);
   if (shared->half_band[1].coefs != shared->half_band[0].coefs)
     free(shared->half_band[1].coefs);
@@ -481,7 +552,9 @@ static void rate_close(rate_t * p)
 
 typedef struct {
   sox_rate_t      out_rate;
-  int             quality, coef_interp;
+  int             quality;
+  double          coef_interp, phase, bandwidth;
+  sox_bool        allow_aliasing;
   rate_t          rate;
   rate_shared_t   shared, * shared_ptr;
 } priv_t;
@@ -489,19 +562,37 @@ typedef struct {
 static int create(sox_effect_t * effp, int argc, char **argv)
 {
   priv_t * p = (priv_t *) effp->priv;
-  char * dummy_p, * found_at, * bws = "-qlmhvu", * nums = "123";
+  int c;
+  char * dummy_p, * found_at, * opts = "+i:b:p:MILasqlmhv", * qopts = opts +12;
 
-  p->quality = p->coef_interp = -1;
+  p->quality = -1;
+  p->phase = 50;
   p->shared_ptr = &p->shared;
-  while (argc && strchr(bws, *argv[0])) {
-    char c, * q = *argv[0] == '-'? *argv + 1 : *argv;
-    while ((c = *q++)) {
-      if      ((found_at = strchr(bws+1, c))) p->quality = found_at - bws -1;
-      else if ((found_at = strchr(nums, c))) p->coef_interp = found_at - nums;
-      else return lsx_usage(effp);
-    }
-    argc--; argv++;
+
+  while ((c = getopt(argc, argv, opts)) != -1) switch (c) {
+    GETOPT_NUMERIC('i', coef_interp, 1 , 3)
+    GETOPT_NUMERIC('p', phase,  0 , 100)
+    GETOPT_NUMERIC('b', bandwidth,  100 - MAX_TBW3, 99.7)
+    case 'M': p->phase =  0; break;
+    case 'I': p->phase = 25; break;
+    case 'L': p->phase = 50; break;
+    case 's': p->bandwidth = 99; break;
+    case 'a': p->allow_aliasing = sox_true; break;
+    default: if ((found_at = strchr(qopts, c))) p->quality = found_at - qopts;
+      else {lsx_fail("unknown option `-%c'", optopt); return lsx_usage(effp);}
   }
+  argc -= optind, argv += optind;
+
+  if ((unsigned)p->quality < 2 && (p->bandwidth || p->phase != 50 || p->allow_aliasing)) {
+    lsx_fail("override options not allowed with this quality level");
+    return SOX_EOF;
+  }
+
+  if (p->bandwidth && p->bandwidth < 100 - MAX_TBW3A && p->allow_aliasing) {
+    lsx_fail("minimum allowed bandwidth with aliasing is %g%%", 100 - MAX_TBW3A);
+    return SOX_EOF;
+  }
+
   if (argc) {
     if ((p->out_rate = lsx_parse_frequency(*argv, &dummy_p)) <= 0 || *dummy_p)
       return lsx_usage(effp);
@@ -521,16 +612,16 @@ static int start(sox_effect_t * effp)
 
   effp->out_signal.channels = effp->in_signal.channels;
   effp->out_signal.rate = out_rate;
-  rate_init(&p->rate, p->shared_ptr, effp->in_signal.rate / out_rate, p->quality, p->coef_interp);
+  rate_init(&p->rate, p->shared_ptr, effp->in_signal.rate / out_rate,
+      p->quality, (int)p->coef_interp - 1, p->phase, p->bandwidth, p->allow_aliasing);
   return SOX_SUCCESS;
 }
 
 static int flow(sox_effect_t * effp, const sox_sample_t * ibuf,
-                sox_sample_t * obuf, sox_size_t * isamp, sox_size_t * osamp)
+                sox_sample_t * obuf, size_t * isamp, size_t * osamp)
 {
   priv_t * p = (priv_t *)effp->priv;
-  sox_size_t i;
-  size_t odone = *osamp; /* See comment in tempo.c */
+  size_t i, odone = *osamp;
 
   sample_t const * s = rate_output(&p->rate, NULL, &odone);
   for (i = 0; i < odone; ++i) *obuf++ = TO_SOX(*s++, effp->clips);
@@ -545,10 +636,10 @@ static int flow(sox_effect_t * effp, const sox_sample_t * ibuf,
   return SOX_SUCCESS;
 }
 
-static int drain(sox_effect_t * effp, sox_sample_t * obuf, sox_size_t * osamp)
+static int drain(sox_effect_t * effp, sox_sample_t * obuf, size_t * osamp)
 {
   priv_t * p = (priv_t *)effp->priv;
-  static sox_size_t isamp = 0;
+  static size_t isamp = 0;
   rate_flush(&p->rate);
   return flow(effp, 0, obuf, &isamp, osamp);
 }
@@ -563,15 +654,27 @@ static int stop(sox_effect_t * effp)
 sox_effect_handler_t const * sox_rate_effect_fn(void)
 {
   static sox_effect_handler_t handler = {
-    "rate", "[-q|-l|-m|-h|-v] [RATE[k]]"
-    "\n\tQuality        BW %    Rej dB    Typical Use"
-    "\n -q\tquick & dirty  n/a   ~30 @ Fs/4  playback on ancient hardware"
-    "\n -l\tlow            80       100      playback on old hardware"
-    "\n -m\tmedium         99       100      audio playback"
-    "\n -h\thigh           99       125      16-bit mastering (use with dither)"
-    "\n -v\tvery high      99       175      24-bit mastering"
-    /* "\n -u\tultra high     99.7     175      " */
-    , SOX_EFF_RATE, create, start, flow, drain, stop, NULL, sizeof(priv_t)
+    "rate", 0, SOX_EFF_RATE | SOX_EFF_GETOPT,
+    create, start, flow, drain, stop, 0, sizeof(priv_t)
   };
+  static char const * lines[] = {
+    "[-q|-l|-m|-h|-v] [override-options] RATE[k]",
+    "                    BAND-",
+    "     QUALITY        WIDTH  REJ dB   TYPICAL USE",
+    " -q  quick          n/a  ~30 @ Fs/4 playback on ancient hardware",
+    " -l  low            80%     100     playback on old hardware",
+    " -m  medium         95%     100     audio playback",
+    " -h  high (default) 95%     125     16-bit mastering (use with dither)",
+    " -v  very high      95%     175     24-bit mastering",
+    "              OVERRIDE OPTIONS (only with -m, -h, -v)",
+    " -M/-I/-L     Phase response = minimum/intermediate/linear(default)",
+    " -s           Steep filter (band-width = 99%)",
+    " -a           Allow aliasing above the pass-band",
+    " -b 74-99.7   Any band-width %",
+    " -p 0-100     Any phase response (0 = minimum, 25 = intermediate,",
+    "              50 = linear, 100 = maximum)",
+  };
+  static char * usage;
+  handler.usage = lsx_usage_lines(&usage, lines, array_length(lines));
   return &handler;
 }
